@@ -17,6 +17,5 @@ pub use serialize::serialize;
 #[cfg(feature = "loaders")]
 pub use loaders::{
     UniLoader, FileReader, UniNodeLoadError, register_loader,
-    is_available_loader, set_default_reader, from_file, from_string,
-    from_file_base,
+    is_available_loader, set_default_reader, load, from_string
 };
