@@ -831,7 +831,7 @@ impl<'de> de::Deserializer<'de> for &'de UniNode {
     {
         let (variant, value) = match self {
             UniNode::Object(value) => {
-                let mut iter = value.into_iter();
+                let mut iter = value.iter();
                 let (variant, value) = match iter.next() {
                     Some(v) => v,
                     None => {
@@ -931,7 +931,7 @@ struct MapRefDeserializer<'de> {
 impl<'de> MapRefDeserializer<'de> {
     fn new(map: &'de Object) -> Self {
         MapRefDeserializer {
-            iter: map.into_iter(),
+            iter: map.iter(),
             value: None,
         }
     }
@@ -1328,8 +1328,8 @@ fn deserialize_seq_test() {
 
 #[test]
 fn deserialize_tuple_test() {
-    let tup = ("one".to_string(), 1, 3.14);
-    tests::deserialize_test(unode!("one", 1, 3.14), tup);
+    let tup = ("one".to_string(), 1, 3.18);
+    tests::deserialize_test(unode!("one", 1, 3.18), tup);
 }
 
 #[test]
@@ -1405,7 +1405,7 @@ fn deserialize_struct_test() {
 
     let data = Test {
         int: 42,
-        float: 3.14,
+        float: 3.18,
         text: "hello".to_string(),
         data: vec![Point::new(1, 2), Point::new(2, 3), Point::new(3, 4)],
         node: 10.into(),
@@ -1414,7 +1414,7 @@ fn deserialize_struct_test() {
 
     let node = unode! {
         "int" => 42u32,
-        "float" => 3.14,
+        "float" => 3.18,
         "text" => "hello",
         "data" => unode![
             unode!{"x" => 1, "y" => 2},
