@@ -12,8 +12,7 @@ macro_rules! unode {
         $crate::UniNode::from($value)
     );
     ($($values:expr),+ $(,)?) => ({
-        let mut data = Vec::new();
-        $(data.push(unode!($values));)+
+        let data = vec![$(unode!($values),)+];
         $crate::UniNode::Array(data)
     });
     ($($key:expr => $value:expr,)+) => (
