@@ -84,18 +84,11 @@ impl UniNode {
     }
 
     pub fn is_null(&self) -> bool {
-        match self {
-            UniNode::Null => true,
-            _ => false,
-        }
+        matches!(self, UniNode::Null)
     }
 
     pub fn is_some_int(&self) -> bool {
-        match self {
-            UniNode::Integer(_) => true,
-            UniNode::UInteger(_) => true,
-            _ => false,
-        }
+        matches!(self, UniNode::Integer(_) | UniNode::UInteger(_))
     }
 
     fn invalid_error(&self, expected: Expected) -> UniNodeError {
@@ -270,7 +263,7 @@ impl UniNode {
             I: Iterator<Item = &'b str>,
         {
             if let Some(name) = names.next() {
-                if name.len() > 0 {
+                if !name.is_empty() {
                     if let UniNode::Object(tbl) = root {
                         if let Some(chd) = tbl.get(name) {
                             return find_path(chd, names);
@@ -295,7 +288,7 @@ impl UniNode {
             I: Iterator<Item = &'b str>,
         {
             if let Some(name) = names.next() {
-                if name.len() > 0 {
+                if !name.is_empty() {
                     if let UniNode::Object(tbl) = root {
                         if let Some(chd) = tbl.get_mut(name) {
                             return find_path(chd, names);
@@ -333,6 +326,7 @@ impl UniNode {
                 },
                 UniNode::Object(o) if src.is_object() => {
                     if let UniNode::Object(src) = src {
+                        #[allow(clippy::map_entry)]
                         for (key, node) in src {
                             if o.contains_key(&key) {
                                 merge_node(o.get_mut(&key).unwrap(), node);
@@ -751,7 +745,7 @@ fn value_as_uinteger_test() {
 #[test]
 fn value_as_float_test() {
     fn float_test(value: UniNode, val: f64) {
-        assert_eq!(value.as_float().unwrap(), val);
+        assert!((value.as_float().unwrap() - val).abs() < f64::EPSILON);
     }
     float_test(unode!(true), 1.0);
     float_test(unode!(false), 0.0);
@@ -872,10 +866,10 @@ fn value_get_test() {
         "arr" => unode!["one", 2, 3.3],
     );
 
-    assert_eq!(val.get_bool("bool").unwrap(), true);
+    assert!(val.get_bool("bool").unwrap());
     assert_eq!(val.get_int("int").unwrap(), 33);
     assert_eq!(val.get_uint("uint").unwrap(), 12);
-    assert_eq!(val.get_float("float").unwrap(), 1.2);
+    assert!((val.get_float("float").unwrap() - 1.2).abs() < f64::EPSILON);
     assert_eq!(val.get_str("str").unwrap(), "hello");
     assert_eq!(val.get_bytes("bytes").unwrap(), vec![1, 2, 3]);
     assert_eq!(val.get_str("opt").unwrap(), "opt");
@@ -902,7 +896,7 @@ impl Display for UniNode {
             UniNode::Bytes(val) => write!(f, "{:?}", val),
             UniNode::Array(val) => {
                 write!(f, "[")?;
-                for (i, item) in val.into_iter().enumerate() {
+                for (i, item) in val.iter().enumerate() {
                     if i > 0 {
                         write!(f, ", ")?;
                     }
@@ -912,7 +906,7 @@ impl Display for UniNode {
             },
             UniNode::Object(val) => {
                 write!(f, "{{")?;
-                for (i, item) in val.into_iter().enumerate() {
+                for (i, item) in val.iter().enumerate() {
                     if i > 0 {
                         write!(f, ", ")?;
                     }
